// URL of the CSV data
const dataUrl =
  'https://gist.githubusercontent.com/VarshaYarragunta/2c12648151358d5d8086acfba2cf0b16/raw/10e6007cfdfca35feb51ac076163ee41bfe6869b/Salary.csv';

// Load data from the CSV file
d3.csv(dataUrl).then((data) => {
  // Convert numeric strings to numbers for 'Age' and 'Salary'
  data.forEach((d) => {
    d.Age = +d.Age;
    d.Salary = +d.Salary;
  });

  // Set dimensions and margins for the graph
  const margin = {
      top: 50,
      right: 50,
      bottom: 70,
      left: 70,
    },
    width = 1060 - margin.left - margin.right,
    height = 800 - margin.top - margin.bottom;

  // Append SVG object to the body and set dimensions
  const svg = d3
    .select('body')
    .append('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  // Adding title to the graph
  svg
    .append('text')
    .attr('x', width / 2)
    .attr('y', 0 - margin.top / 2)
    .attr('text-anchor', 'middle')
    .style('font-size', '24px')
    .style('text-decoration', 'underline')
    .text('Age vs. Salary Scatter Plot');

  // X axis for Age
  const x = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d.Age)])
    .range([0, width]);
  svg
    .append('g')
    .attr('transform', `translate(0,${height})`)
    .call(d3.axisBottom(x));

  // Adding X axis label
  svg
    .append('text')
    .attr(
      'transform',
      `translate(${width / 2}, ${height + margin.top + 10})`,
    )
    .style('text-anchor', 'middle')
    .text('Age');

  // Y axis for Salary
  const y = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d.Salary)])
    .range([height, 0]);
  svg.append('g').call(d3.axisLeft(y));

  // Adding Y axis label
  svg
    .append('text')
    .attr('transform', 'rotate(-90)')
    .attr('y', 0 - margin.left)
    .attr('x', 0 - height / 2)
    .attr('dy', '1em')
    .style('text-anchor', 'middle')
    .text('Salary');

  // Add dots
  svg
    .selectAll('.dot')
    .data(data)
    .enter()
    .append('circle')
    .attr('class', 'dot')
    .attr('r', 5)
    .attr('cx', (d) => x(d.Age))
    .attr('cy', (d) => y(d.Salary))
    .style('fill', '#69b3a2');
});
